@@ -1,9 +1,8 @@
-# ABSTRACT: BeLike::GENEHACK when you zilla your dist
-
 package Dist::Zilla::PluginBundle::GENEHACK;
-$Dist::Zilla::PluginBundle::GENEHACK::VERSION = '0.6_02';
+$Dist::Zilla::PluginBundle::GENEHACK::VERSION = '0.6_03';
 our $AUTHORITY = 'cpan:GENEHACK';
 
+# ABSTRACT: BeLike::GENEHACK when you zilla your dist
 
 
 use Moose;
@@ -129,7 +128,7 @@ sub configure {
 
     # git magic
     'Git::Tag',
-    'Git::Commit',
+    ['Git::Commit' => { add_files_in => 'releases/' } ],
 
     # install dist after release
     [ 'InstallRelease' => { install_command => 'cpanm .' } ] ,
@@ -169,7 +168,7 @@ Dist::Zilla::PluginBundle::GENEHACK - BeLike::GENEHACK when you zilla your dist
 
 =head1 VERSION
 
-version 0.6_02
+version 0.6_03
 
 =head1 SYNOPSIS
 
@@ -213,6 +212,7 @@ this:
     [Test::Compile]
     [Git::Tag]
     [Git::Commit]
+    add_files_in = releases/
     [InstallRelease]
     install_command='cpanm .'
     [Twitter]
